"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Debugger = void 0;
Object.defineProperty(exports, "DebuggerSwitcher", {
  enumerable: true,
  get: function () {
    return _components.DebuggerSwitcher;
  }
});
Object.defineProperty(exports, "addLogItem", {
  enumerable: true,
  get: function () {
    return _utils.addLogItem;
  }
});
Object.defineProperty(exports, "getCompleteDebugItems", {
  enumerable: true,
  get: function () {
    return _utils.getCompleteDebugItems;
  }
});
Object.defineProperty(exports, "logToDebugger", {
  enumerable: true,
  get: function () {
    return _utils.logToDebugger;
  }
});
Object.defineProperty(exports, "resetLogItems", {
  enumerable: true,
  get: function () {
    return _utils.resetLogItems;
  }
});
Object.defineProperty(exports, "toggleDebugger", {
  enumerable: true,
  get: function () {
    return _utils.toggleDebugger;
  }
});
Object.defineProperty(exports, "useDebugItems", {
  enumerable: true,
  get: function () {
    return _utils.useDebugItems;
  }
});
Object.defineProperty(exports, "useShowDebugger", {
  enumerable: true,
  get: function () {
    return _utils.useShowDebugger;
  }
});

var _reactNative = require("react-native");

var _react = _interopRequireWildcard(require("react"));

var _utils = require("./utils");

var _clipboard = _interopRequireDefault(require("@react-native-clipboard/clipboard"));

var _useShowDebugger = require("./utils/useShowDebugger");

var _styles = require("./styles");

var _state = require("./state");

var _ListItem = require("./components/ListItem");

var _DebuggerSwitcher = require("./components/DebuggerSwitcher");

var _getCompleteDebugItems = require("./utils/getCompleteDebugItems");

var _components = require("./components");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Separator = () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: _styles.styles.separator
});

const EmptySection = () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: _styles.styles.emptyWrapper
}, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
  style: _styles.styles.emptyText
}, "No events captured yet"));

const keyExtractor = _ref => {
  let {
    id
  } = _ref;
  return `${id}`;
};

const renderItem = _ref2 => {
  let {
    item
  } = _ref2;
  return /*#__PURE__*/_react.default.createElement(_ListItem.ListItem, {
    item: item
  });
};

const persistKey = '[QA-DEBUGGER]: Persistent items';

const Debugger = /*#__PURE__*/_react.default.memo(_ref3 => {
  let {
    getGlobalState,
    persistentStore,
    disableSnapshots,
    sendToDefaultValue,
    customSendRequest,
    stripPersistentData = Boolean(persistentStore),
    hideSwitcher
  } = _ref3;
  const {
    height
  } = (0, _reactNative.useWindowDimensions)();
  const [debugItems, addItems] = (0, _utils.useDebugItems)();
  const [show] = (0, _useShowDebugger.useShowDebugger)();
  const [sendTo, setSendTo] = (0, _react.useState)(sendToDefaultValue ?? '');
  const [forceHeight, setForceHeight] = (0, _react.useState)(null);
  const [preserve, setPreserve] = (0, _react.useState)(false);
  const preserveInitiated = (0, _react.useRef)(false);
  (0, _react.useEffect)(() => {
    _state.DebuggerState.isMounted = true;
    return () => {
      _state.DebuggerState.isMounted = false;
    };
  }, []);

  const getPersistValue = async () => {
    if (persistentStore) {
      const value = await persistentStore.get(persistKey);

      if (value) {
        try {
          const pItems = JSON.parse(value);
          const itemsToAdd = Array.isArray(pItems) ? pItems : [];
          addItems(...itemsToAdd);
          preserveInitiated.current = true;
          persistentStore.remove(persistKey);
          setPreserve(true);
        } catch {
          preserveInitiated.current = true;
        }
      }
    }
  };

  (0, _react.useEffect)(() => {
    getPersistValue(); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  (0, _react.useEffect)(() => {
    _state.DebuggerState.getGlobalState = getGlobalState;
    _state.DebuggerState.areSnapshotsEnabled = Boolean(!disableSnapshots && getGlobalState);
  }, [getGlobalState, disableSnapshots]);

  const handleClose = () => (0, _utils.toggleDebugger)(false);

  const handleGetGlobalState = async () => {
    try {
      if (getGlobalState) {
        _clipboard.default.setString(JSON.stringify(await (getGlobalState === null || getGlobalState === void 0 ? void 0 : getGlobalState())));

        _reactNative.Alert.alert('Global state copied to clipboard');
      }
    } catch {}
  };

  const handleCopyItems = async () => {
    try {
      const completeDebugItems = await (0, _getCompleteDebugItems.getCompleteDebugItems)(debugItems);
      const clipboardString = JSON.stringify(completeDebugItems);

      _clipboard.default.setString(clipboardString);

      const saved = await _clipboard.default.getString();

      if (saved === clipboardString) {
        _reactNative.Alert.alert('Items copied to clipboard');
      } else {
        _reactNative.Alert.alert('Failed to copy, might be too many items, try sending instead');
      }
    } catch {
      _reactNative.Alert.alert('Failed to copy, try sending instead');
    }
  };

  const handleSend = async () => {
    if (!sendTo) return;
    const completeDebugItems = await (0, _getCompleteDebugItems.getCompleteDebugItems)(debugItems);

    if (sendTo.includes('@') && !sendTo.includes('/')) {
      const canSendEmail = await _reactNative.Linking.canOpenURL(`mailto:${sendTo}`);

      if (canSendEmail) {
        _reactNative.Linking.openURL(`mailto:${sendTo}?subject=logs${new Date().toISOString()}&body=${JSON.stringify(completeDebugItems)}`);
      } else {
        _reactNative.Alert.alert('Cannot send email');
      }
    } else if (customSendRequest && typeof customSendRequest === 'function') {
      customSendRequest(sendTo, completeDebugItems);
    } else {
      // 	https://webhook.site/ab0c53e9-a21e-4b46-ab4c-02fe9b6cac93
      fetch(sendTo.trim(), {
        method: 'POST',
        body: JSON.stringify(completeDebugItems)
      }).then(() => {
        _reactNative.Alert.alert('Success', `Logs sent to ${sendTo.trim()}`);
      }).catch(() => {
        _reactNative.Alert.alert('Error', `Could not send logs to ${sendTo.trim()}`);
      });
    }
  };

  (0, _react.useEffect)(() => {
    const openListener = _reactNative.Keyboard.addListener('keyboardDidShow', _ref4 => {
      let {
        endCoordinates
      } = _ref4;
      setForceHeight(height - endCoordinates.height - 24);
    });

    const hideListener = _reactNative.Keyboard.addListener('keyboardDidHide', () => {
      setForceHeight(null);
    });

    return () => {
      openListener.remove();
      hideListener.remove();
    };
  }, [height]);

  const toggleSwitch = () => setPreserve(v => !v);

  (0, _react.useEffect)(() => {
    if (persistentStore && !preserve && preserveInitiated.current) {
      persistentStore.remove(persistKey);
    }
  }, [persistentStore, preserve]);
  (0, _react.useEffect)(() => {
    if (preserve && persistentStore) {
      try {
        const last10Errors = debugItems.filter(item => item.logType === 'error' && !item.preserved).slice(-10).reduce((accum, item) => {
          return [...accum, { ...item,
            data: stripPersistentData ? JSON.stringify((item === null || item === void 0 ? void 0 : item.data) || '').slice(0, 500) : item === null || item === void 0 ? void 0 : item.data,
            preserved: true,
            snapshot: undefined,
            snapshotReadable: undefined
          }];
        }, []);
        persistentStore.set(persistKey, JSON.stringify(last10Errors));
      } catch {}
    }
  }, [debugItems, persistentStore, preserve, stripPersistentData]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, show ? /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: [_styles.styles.wrapper, forceHeight ? {
      maxHeight: forceHeight
    } : false]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.titleWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.title
  }, "QA DEBUGGER")), /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    keyExtractor: keyExtractor,
    contentContainerStyle: _styles.styles.flex,
    ItemSeparatorComponent: Separator,
    data: debugItems,
    ListEmptyComponent: EmptySection,
    renderItem: renderItem
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, " Send to"), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    style: _styles.styles.sendToInput,
    value: sendTo,
    onChangeText: setSendTo
  }), Boolean(sendTo) && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: _styles.styles.sendButton,
    onPress: handleSend
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Send"))), Boolean(getGlobalState) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleGetGlobalState,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Copy global state"))), Boolean(persistentStore) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: toggleSwitch,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Switch, {
    style: {
      transform: [{
        scale: 0.75
      }]
    },
    onValueChange: toggleSwitch,
    value: preserve
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "\xA0\xA0Preserve 10 last errors"))), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleCopyItems,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Copy items")), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: _utils.resetLogItems,
    style: [_styles.styles.button, _styles.styles.centralButton]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Clear")), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleClose,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Close")))) : null, !hideSwitcher && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.switcher
  }, /*#__PURE__*/_react.default.createElement(_DebuggerSwitcher.DebuggerSwitcher, null)));
});

exports.Debugger = Debugger;
//# sourceMappingURL=index.js.map