"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useShowDebugger = exports.toggleDebugger = exports.getLocalId = void 0;

var _react = require("react");

let currentShowDebugger = false;
const callbacks = {};

const toggleDebugger = show => {
  currentShowDebugger = typeof show === 'boolean' ? show : !currentShowDebugger;
  Object.values(callbacks).forEach(callback => {
    callback === null || callback === void 0 ? void 0 : callback(currentShowDebugger);
  });
};

exports.toggleDebugger = toggleDebugger;

const getGenIdFn = () => {
  let lastId = 0;
  return () => `${lastId++}`;
};

const getLocalId = getGenIdFn();
exports.getLocalId = getLocalId;

const getUseShowDebugger = () => {
  return () => {
    const [show, setShowDebugger] = (0, _react.useState)(currentShowDebugger);
    (0, _react.useEffect)(() => {
      const uid = getLocalId();

      callbacks[uid] = newShow => setShowDebugger(newShow);

      return () => {
        delete callbacks[uid];
      };
    }, []);
    return [show, toggleDebugger];
  };
};

const useShowDebugger = getUseShowDebugger();
exports.useShowDebugger = useShowDebugger;
//# sourceMappingURL=useShowDebugger.js.map