import { Pressable, Text, useWindowDimensions, View } from 'react-native';
import React, { useEffect, useMemo, useState } from 'react';
import { styles, getIconStyles } from './styles';
import { colors } from '../../constants';
import { reverseUndefFallback } from '../../utils/findDiff';

const renderPreview = item => {
  if (Array.isArray(item)) {
    return item.length ? '[...]' : '[]';
  }

  if (item && typeof item === 'object') {
    return Object.keys(item).length ? '{...}' : '{}';
  }

  return `${item}`;
};

const isObjectArray = (item, yes, no) => Array.isArray(item) ? yes : no;

export const DebuggerItem = /*#__PURE__*/React.memo(_ref => {
  let {
    item,
    prefix = '',
    onToggle
  } = _ref;
  const {
    width
  } = useWindowDimensions();
  const [show, setShow] = useState(false);
  const isObject = item && typeof item === 'object';
  useEffect(() => {
    onToggle === null || onToggle === void 0 ? void 0 : onToggle(show); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [show]);

  const toggleSection = () => setShow(v => !v);

  const preview = useMemo(() => `${prefix} ${isObject ? `${isObjectArray(item, '[', '{')} ${Object.entries(item).reduce((accum, _ref2) => {
    let [key, value] = _ref2;
    return [...accum, `${key} : ${value && typeof value === 'object' ? renderPreview(value) : `${reverseUndefFallback(value)}`}`];
  }, []).join(', ')} ${isObjectArray(item, ']', '}')}` : `${item}`}`, // eslint-disable-next-line react-hooks/exhaustive-deps
  []);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.wrapper
  }, /*#__PURE__*/React.createElement(Pressable, {
    style: styles.pressable // onLongPress={emptyFn}
    ,
    onPress: toggleSection
  }, /*#__PURE__*/React.createElement(View, {
    style: getIconStyles({
      show,
      isObject
    })
  }), /*#__PURE__*/React.createElement(Text, {
    style: {
      color: colors.textMain,
      maxWidth: prefix ? undefined : width - 74
    },
    numberOfLines: !isObject && show ? undefined : 1 // selectable={!isObject}

  }, preview)), show && item && typeof item === 'object' && /*#__PURE__*/React.createElement(View, {
    style: styles.recursionSpacer
  }, Object.entries(item).map((_ref3, index) => {
    let [key, value] = _ref3;
    return /*#__PURE__*/React.createElement(DebuggerItem, {
      key: index,
      prefix: `${key}: `,
      item: value
    });
  })));
});
//# sourceMappingURL=index.js.map